@@ -1,7 +1,7 @@
 import pytest
 from requests.exceptions import HTTPError
 
-import pandas_datareader.data as web
+from pandas_datareader import data as web
 
 pytestmark = pytest.mark.stable
 
@@ -21,6 +21,13 @@ class TestMoex(object):
             df = web.DataReader(
                 ["GAZP", "SIBN"], "moex", start="2019-12-26", end="2019-12-26"
             )
-            assert df.size == 740
+            assert len(df) == 2
+        except HTTPError as e:
+            pytest.skip(e)
+
+    def test_moex_datareader_filter(self):
+        try:
+            df = web.DataReader("SBER", "moex", start="2020-07-14", end="2020-07-14")
+            assert len(df) == 1
         except HTTPError as e:
             pytest.skip(e)
